
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.29.19',
    'branch_nick': 'release-1.29-LTS',
    'revision_id': '6b0d5297b33fe8dcd15d46b05fe60856026d7310',
    'revno': 12116
}
